pub enum ProbeDispatch {
Consumed,
Passthrough(HoprPseudonym, ApplicationDataIn),
}Expand description
Result of classifying one incoming message through the probe layer.
Variants
Consumed
The message was a probe message and has been consumed internally.
Passthrough(HoprPseudonym, ApplicationDataIn)
The message was not related to probing; caller should route it further.